@@ -1,17 +1,20 @@
 import machine
 import time
 from growmax.sensors import adafruit_scd4x
+from growmax.utils.i2c import i2c_channel_pins
+from growmax.utils.mcu import get_gpio_for_mcu
 
 
 def init_adafruit_scd4x(i2c_channel=0):
-    pin_scl = 1
-    pin_sda = 0
-    if i2c_channel == 1:
-        pin_scl = 19
-        pin_sda = 18
+    pin_scl, pin_sda = i2c_channel_pins(i2c_channel)
     try:
         time.sleep(2.0)
-        i2c = machine.I2C(i2c_channel, scl=machine.Pin(pin_scl), sda=machine.Pin(pin_sda), freq=5000)
+        i2c = machine.I2C(
+            i2c_channel,
+            scl=machine.Pin(get_gpio_for_mcu(pin_scl)),
+            sda=machine.Pin(get_gpio_for_mcu(pin_sda)),
+            freq=5000
+        )
         time.sleep(2.0)
         scd4x = adafruit_scd4x.SCD4X(i2c)
         time.sleep(2.0)
@@ -25,6 +28,7 @@ def init_adafruit_scd4x(i2c_channel=0):
         print(e)
     return None
 
+
 def read_adafruit_scd4x(scd4x):
     if scd4x.data_ready:
         ppm_carbon_dioxide = scd4x.CO2
